#[non_exhaustive]pub enum PrefixedDecodeError {
InvalidPrefix {
expected: String,
},
Base32Decode(Base32DecodeError),
ConsensusDecode(DecodeError),
}Expand description
Failure to decode a prefixed base 32 string into a value.
The byte offset in a Base32DecodeError::InvalidCharacter source refers
to the payload after the prefix was stripped and the input was lowercased,
not to the string the caller supplied.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidPrefix
The string does not start with the expected prefix.
Base32Decode(Base32DecodeError)
The payload is not valid base 32.
ConsensusDecode(DecodeError)
The decoded bytes are not a valid consensus encoding of the target type.